Code Reviews with Gerrit
========================

Savanna uses the `Gerrit`_ tool to review proposed code changes. The review site
is http://review.openstack.org.

Gerrit is a complete replacement for Github pull requests. `All Github pull
requests to the Savanna repository will be ignored`.

See `Gerrit Workflow Quick Reference`_ for information about how to get
started using Gerrit. See `Gerrit, Jenkins and Github`_ for more detailed
documentation on how to work with Gerrit.

.. _Gerrit: http://code.google.com/p/gerrit
.. _Gerrit, Jenkins and Github: http://wiki.openstack.org/GerritJenkinsGithub
.. _Gerrit Workflow Quick Reference: http://wiki.openstack.org/GerritWorkflow